{% extends "zinnia/base.html" %}
{% load i18n comments zinnia_tags %}

{% block title %}{{ object.title }}{% endblock title %}

{% block meta-description %}{{ object.excerpt|safe }}{% endblock meta-description %}

{% block meta-keywords %}{% if object.tags %}{{ object.tags }}{% else %}{{ block.super }}{% endif %}{% endblock meta-keywords %}

{% block link %}{% endblock link %}

{% block body-class %}entry entry-{{ object.pk }}{% if object.featured %} featured{% endif %} year-{{ object.creation_date|date:"Y" }} month-{{ object.creation_date|date:"m" }} week-{{ object.creation_date|date:"W" }} day-{{ object.creation_date|date:"d" }}{% endblock body-class %}

{% block content %}
{{ block.super }}

{% block entry-content %}
  {% include object.content_template with object_content=object.html_content|safe %}
{% endblock entry-content %}

{% block entry-widgets %}{% endblock entry-widgets %}
{% block entry-comments %}{% endblock entry-comments %}
{% block entry-pingbacks %}{% endblock entry-pingbacks %}
{% block entry-trackbacks %}{% endblock entry-trackbacks %}
{% block entry-comments-form %}{% endblock entry-comments-form %}

{% endblock content %}

{% block admin-tools %}
{% if perms.zinnia.change_entry %}
<li>
  <a href="{% url 'admin:zinnia_entry_change' object.pk %}" title="{% trans 'Edit the entry' %}">
    {% trans "Edit the entry" %}
  </a>
</li>
{% endif %}
{% endblock admin-tools %}
