{% extends "base.html" %}

{% block title %}500 Internal Server Error{% endblock %}

{% block content %}
<h2>500 Internal Server Error</h2>
<p>Autsch! Wir haben einen Bock geschossen. Das System hat uns über das Problem schon benachrichtigt,
	wir kümmern uns darum.</p>
{% endblock %}
