{% extends "cms_base.html" %}
{% load link_list %}

{% block content %}
{{ block.super }}
{% get_link_list "links" as links, category %}
{% if links %}
<div id="bookmarks">
	{% for link in links %}
	<h2>{{ link.title }}</h2>
	{{ link.description|linebreaks }}
	<p class="link"><a href="{{ link.href }}" target="_blank">{{ link.href|slice:"7:-1" }}</a></p>
	{% endfor %}
</div>
{% endif %}
{% endblock %}
