{% extends "zinnia/entry_list.html" %}
{% load i18n %}

{% block meta-description %}{% trans "Archives" %} {{ day|date:"DATE_FORMAT" }}{% endblock meta-description %}

{% block title %}{% trans "Archives" %} {{ day|date:"DATE_FORMAT" }}{% endblock title %}

{% block body-class %}{{ block.super }} archive date day year-{{ day|date:"Y" }} month-{{ day|date:"m" }} week-{{ day|date:"W" }} day-{{ day|date:"d" }}{% endblock body-class %}

{% block content-title %}
<h1>{% trans "Archives" %} {{ day|date:"DATE_FORMAT" }}</h1>
{% endblock content-title %}

{% block content-related %}
{% if previous_day %}
<h3>{% trans "Previous day" %}</h3>
<p>
  <a href="{% url 'zinnia_entry_archive_day' previous_day|date:"Y" previous_day|date:"m" previous_day|date:"d" %}" rel="archives">{{ previous_day|date:"DATE_FORMAT" }}</a>
</p>
{% endif %}
{% if next_day %}
<h3>{% trans "Next day" %}</h3>
<p>
  <a href="{% url 'zinnia_entry_archive_day' next_day|date:"Y" next_day|date:"m" next_day|date:"d" %}" rel="archives">{{ next_day|date:"DATE_FORMAT" }}</a>
</p>
{% endif %}

<h3>{% trans "Archives" %}</h3>
<ul>
  <li>
    <a href="{% url 'zinnia_entry_archive_year' day|date:"Y" %}" rel="archives">{{ day|date:"Y" }}</a>
  </li>
  {% if previous_month %}
  <li>
    <a href="{% url 'zinnia_entry_archive_month' previous_month|date:"Y" previous_month|date:"m" %}" rel="archives">{{ previous_month|date:"YEAR_MONTH_FORMAT" }}</a>
  </li>
  {% endif %}
  <li>
    <a href="{% url 'zinnia_entry_archive_month' day|date:"Y" day|date:"m" %}" rel="archives">{{ day|date:"YEAR_MONTH_FORMAT" }}</a>
  </li>
  {% if next_month %}
  <li>
    <a href="{% url 'zinnia_entry_archive_month' next_month|date:"Y" next_month|date:"m" %}" rel="archives">{{ next_month|date:"YEAR_MONTH_FORMAT" }}</a>
  </li>
  {% endif %}
</ul>
{% endblock content-related %}
